# What's Changed

- 修复 LLM 请求报错信息被覆盖的问题，增强 LLM 请求错误处理 #243
- 修复 Napcat 接口更新导致 QQ 图片发送失败的问题 #246
- 修复某些请求不能正确应用代理的问题
- 针对 api_base 的明显提示，修改 ollama 模板的 api_base #247
- 支持登出 gewechat，在webchat等地方使用 `/gewe_logout` 指令，这在微信上显示账号下线但是 gewe 仍显示设备在线时很好用
- 添加gewechat适配器过滤器
- help显示AstrBot和webui版本
- 优化webui和主程序更新的协调
- 下载管理面板时显示提示、下载进度和下载速度
- 管理面板前端更新功能入口移入右上角更新按钮，以便统一管理 #245